@@ -1,5 +1,5 @@
 """Simple app to add configuration options to a Django project."""
-from options.constants import FLOAT, INT, STR, FILE, TYPE_CHOICES, CONVERTER
+from options.constants import CONVERTER, FILE, FLOAT, INT, STR, TYPE_CHOICES
 from options.helpers import get_option_model, get_user_option_model
 
 default_app_config = "options.apps.ConfigurationsConfig"
